yakumo.nova.v2.certificate.Manager

Package yakumo :: Package nova :: Package v2 :: Module certificate :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for root certificates in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for root certificates in Compute API v2

Instance Methods | [hide private]
yakumo.nova.v2.certificate.Resource |
create(self, data=`'``__UNDEF__``'`, private_key=`'``__UNDEF__``'`) Register a root certificate | source code
yakumo.base.Resource |
get(self) Aquire an existing resource object | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``data``'``,` `'``data``'``,` <yakumo.mapper.NoopClass obj`...``
| _hidden_methods = ``[``'``update``'``,` `'``list``'``,` `'``find``'``,` `'``find_one``'``]``
| _id_attr = ``'``private_key``'``
| _json_resource_key = ``'``certificate``'``
| _json_resources_key = ``'``certificates``'``
| _url_resource_path = ``'``/os-certificates``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, data=`'``__UNDEF__``'`, private_key=`'``__UNDEF__``'`) | source code
Register a root certificate Parameters: `data` (Certificate data (str, required)) - Certificate data (str, required) `private_key` (Priate key data (str)) - Priate key data (str) Returns: yakumo.nova.v2.certificate.Resource Registered root certificate Overrides: base.Manager.create

### get(self) | source code
Aquire an existing resource object Parameters: `id` - ID Returns: yakumo.base.Resource Resource object Overrides: base.Manager.get (inherited documentation)

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('data', 'data', mapper.Noop), ('private_key', 'private_key', mapper.
      Noop),]